Crate kcr_aquasecurity_github_io

Crate kcr_aquasecurity_github_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the aquasecurity.github.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

aquasecurity.github.io/v1alpha1

  • AquaStarboard
  • ClusterConfigAuditReport
  • ConfigAuditReport

Modules

v1alpha1